@@ -12,7 +12,7 @@ use XTM::baseNameString;
 
 @ISA = qw(Exporter AutoLoader XTM::generic);
 @EXPORT = qw( );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =pod
 
@@ -28,16 +28,34 @@ XTM::baseName - trivial class definition
 
 Generic container for accessor functions.
 
+=cut
+
+sub xml {
+  my $self   = shift;
+  my $writer = shift;
+
+  $writer->startTag ('baseName');
+  $self->scope->xml ($writer) if $self->scope->references;
+  $self->baseNameString->xml ($writer);
+#  foreach my $v ($self->variants ? @{$self->variants} : ()) {
+#     $v->xml ($writer);
+#  }
+  $writer->endTag ('baseName');
+};
+
+=pod
+
 =head1 SEE ALSO
 
 L<XTM>
 
 =head1 AUTHOR INFORMATION
 
-Copyright 2001, Robert Barta <rho@telecoma.net>, All rights reserved.
- 
+Copyright 2001, 2002, Robert Barta <rho@telecoma.net>, All rights reserved.
+
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
+http://www.perl.com/perl/misc/Artistic.html
 
 =cut
 
